Learn R Programming

survsim (version 1.1.2)

simple.surv.sim: Generate a cohort with single-event survival times

Description

Simulation of cohorts in a context of standard survival analysis including several covariates, individual heterogeneity and periods at risk prior and after the start of follow-up.

Usage

simple.surv.sim(n, foltime, dist.ev, anc.ev, beta0.ev, dist.cens="weibull", 
anc.cens, beta0.cens, z=NA, beta=NA, x=NA)

Arguments

n
integer value indicating the desired size of the cohort to be simulated.
foltime
real number that indicates the maximum time of follow-up of the simulated cohort.
dist.ev
time to event distributions, with possible values weibull for the Weibull distribution, lnorm for the log-normal distribution and llogistic for the log-logistic distribution.
anc.ev
ancillary parameter for the time to event distribution.
beta0.ev
$\beta_0$ parameter for the time to event distribution.
dist.cens
string indicating the time to censoring distribution, with possible values weibull for the Weibull distribution, lnorm for the log-normal distribution and llogistic for the log-logistic distribution. If no distributi
anc.cens
real number containing the ancillary parameter for the time to censoring distribution.
beta0.cens
real number containing the $\beta_0$ parameter for the time to censoring distribution.
z
vector with three elements that contains information relative to a random effect used in order to introduce individual heterogeneity. The first element indicates the distribution: "unif" states for a uniform distribution, "gamma"
beta
list of elements indicating the effect of the corresponding covariate. The number of vectors in beta must match the number of covariates. Its default value is NA, indicating that no covariates are included.
x
list of vectors indicating the distribution and parameters of any covariate that the user needs to introduce in the simulated cohort. The possible distributions are "normal" for normal distribution, "unif" for uniform distributio

Value

  • An object of class mult.ev.data.sim. It is a data frame containing the events suffered by the corresponding subjects. The columns of this data frame are detailed below
  • nidan integer number that identifies the subject.
  • statuslogical value indicating if the corresponding event has been suffered or not.
  • starttime at which the follow-up time begins for each event.
  • stoptime at which the follow-up time ends for each event.
  • zIndividual heterogeneity generated according to the specified distribution.
  • xvalue of each covariate randomly generated for each subject in the cohort.

encoding

utf8

References

Kelly PJ, Lim LL. Survival analysis for recurrent event data: an application to childhood infectious diseases. Stat Med 2000 Jan 15;19(1):13-33.

Bender R, Augustin T, Blettner M. Generating survival times to simulate Cox proportional hazards models. Stat Med 2005 Jun 15;24(11):1713-1723.

Moriña D, Navarro A. The R package survsim for the simulation of simple and complex survival data. Journal of Statistical Software 2014 Jul; 59(2):1-21.

See Also

survsim-package, accum, rec.ev.sim, mult.ev.sim, crisk.sim

Examples

Run this code
### A cohort with 1000 subjects, with a maximum follow-up time of 3600 days and two 
### covariates, following a Bernoulli and uniform distribution respectively, and a 
### corresponding beta of -0.4 for the first covariate and a corresponding beta of 0
### for the second covariate. Notice that the time to censorship is assumed to 
### follow a Weibull distribution, as no other distribution is stated.

sim.data <- simple.surv.sim(n=1000, foltime=3600, dist.ev=c('llogistic'),
anc.ev=c(0.69978200185280),beta0.ev=c(5.84298525742252),,anc.cens=1.17783687569519,
beta0.cens=7.39773677281100,z=c("unif", 0.8,1.2), beta=list(c(-0.4),
c(0)), x=list(c("bern", 0.5), c("unif", 0.7, 1.3)))

summary(sim.data)

Run the code above in your browser using DataLab